@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package Dist::Zilla::Plugin::GenerateFile::FromShareDir; # git description: v0.008-3-g0a084ed
+package Dist::Zilla::Plugin::GenerateFile::FromShareDir; # git description: v0.009-7-ge1e8d10
 # ABSTRACT: Create files in the repository or in the build, based on a template located in a dist sharedir
 # KEYWORDS: plugin distribution generate create file sharedir template
 # vim: set ts=8 sts=4 sw=4 tw=115 et :
 
-our $VERSION = '0.009';
+our $VERSION = '0.010';
 
 use Moose;
 with (
@@ -62,7 +62,7 @@ has location => (
 has phase => (
     is => 'ro', isa => enum([ qw(build release) ]),
     lazy => 1,
-    default => 'release',
+    default => 'build',
     init_arg => '-phase',
 );
 
@@ -126,6 +126,15 @@ sub gather_files
 
     if ($self->location eq 'build')
     {
+        if ($self->phase eq 'release')
+        {
+            # we can't generate a file only in the release without doing it now,
+            # which would add it for all builds. Consequently this config combo is
+            # nonsensical and suggests the user is misunderstanding something.
+            $self->log('nonsensical and impossible combination of configs: -location = build, -phase = release');
+            return;
+        }
+
         $self->add_file($file);
     }
     else
@@ -203,7 +212,7 @@ Dist::Zilla::Plugin::GenerateFile::FromShareDir - Create files in the repository
 
 =head1 VERSION
 
-version 0.009
+version 0.010
 
 =head1 SYNOPSIS
 
@@ -311,7 +320,7 @@ There is also a mailing list available for users of this distribution, at
 L<http://dzil.org/#mailing-list>.
 
 There is also an irc channel available for users of this distribution, at
-L<irc://irc.perl.org/#distzilla>.
+L<C<#distzilla> on C<irc.perl.org>|irc://irc.perl.org/#distzilla>.
 
 I am also usually active on irc, as 'ether' at C<irc.perl.org>.
 
