@@ -4,7 +4,7 @@ package Dist::Zilla::Plugin::GenerateFile::ShareDir;
 # ABSTRACT: (DEPRECATED) Create files in the repository or in the build, based on a template located in a dist sharedir
 # vim: set ts=8 sts=4 sw=4 tw=115 et :
 
-our $VERSION = '0.009';
+our $VERSION = '0.010';
 
 use Moose;
 extends 'Dist::Zilla::Plugin::GenerateFile::FromShareDir';
@@ -32,7 +32,7 @@ Dist::Zilla::Plugin::GenerateFile::ShareDir - (DEPRECATED) Create files in the r
 
 =head1 VERSION
 
-version 0.009
+version 0.010
 
 =head1 SYNOPSIS
 
@@ -59,7 +59,7 @@ There is also a mailing list available for users of this distribution, at
 L<http://dzil.org/#mailing-list>.
 
 There is also an irc channel available for users of this distribution, at
-L<irc://irc.perl.org/#distzilla>.
+L<C<#distzilla> on C<irc.perl.org>|irc://irc.perl.org/#distzilla>.
 
 I am also usually active on irc, as 'ether' at C<irc.perl.org>.
 
